# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Re-index Projection Matrix On Basis of Overwrite Table
#' 
#' This function takes matrix indices provided by functions \code{\link{rlefko3}()},
#' \code{\link{rlefko2}()}, \code{\link{flefko3}()}, and \code{\link{flefko2}()} and updates
#' them with information provided in the overwrite table used as input in that
#' function.
#' 
#' @param allst321 Vector containing the original element-by-element matrix index.
#' @param idx321old Vector containing the indices of matrix elements to be updated.
#' @param idx321new Vector containing the replacement matrix element indices.
#' @param convtype Vector denoting survival-transition (1) or fecundity (2).
#' @param eststag3 Vector of new stages in time \emph{t}+1.
#' @param gvnrate Vector of replacement transition values.
#' 
#' @return Vector of updated matrix indices and, where appropriate, replacement
#' matrix element values.
#' 
#' @keywords internal
#' @noRd
ovreplace <- function(allst321, idx321old, idx321new, convtype, eststag3, gvnrate) {
    .Call('_lefko3_ovreplace', PACKAGE = 'lefko3', allst321, idx321old, idx321new, convtype, eststag3, gvnrate)
}

#' Make Horizontal Data Frame Vertical
#' 
#' Function \code{pfj()} powers the R function \code{\link{verticalize3}()}, creating
#' the vertical structure and rearranging the data in that shape.
#' 
#' @param data The horizontal data file.
#' @param stageframe The stageframe object identifying the life history model
#' being operationalized. This should be the full stageframe.
#' @param noyears The number of years or observation periods in the dataset.
#' @param firstyear The first year or time of observation.
#' @param popidcol Column number corresponding to the identity of the population 
#' for each individual.
#' @param patchidcol Column number corresponding to the identity of the patch for
#' each individual.
#' @param individcol Column number corresponding to the identity of each 
#' individual.
#' @param blocksize The number of variables corresponding to each time step in 
#' the input dataset designated in \code{data}.
#' @param xcol Column number corresponding to the x coordinate of each individual
#' in Cartesian space.
#' @param ycol Column number corresponding to the y coordinate of each individual
#' in Cartesian space.
#' @param juvcol Column number that marks individuals in immature stages within
#' the dataset.
#' @param size1col Column number corresponding to the first or main size variable 
#' associated with the first year or observation time in the dataset.
#' @param size2col Column number corresponding to the second size variable
#' associated with the first year or observation time in the dataset.
#' @param size3col Column number corresponding to the third size variable
#' associated with the first year or observation time in the dataset.
#' @param repstr1col Column number corresponding to the main variable coding the
#' production of reproductive structures associated with the first year or 
#' observation period in the input dataset.
#' @param repstr2col Column number corresponding to a secone variable coding the
#' production of reproductive structures associated with the first year or 
#' observation period in the input dataset.
#' @param fec1col Column number corresponding to the main variable coding for
#' fecundity associated with the first year or observation period in the dataset.
#' @param fec2col Column number corresponding to a second variable coding for
#' fecundity associated with the first year or observation period in the dataset.
#' @param alive1col Column number that details whether an individual is alive at
#' a given time.
#' @param dead1col Column number that details whether an individual is dead at
#' a given time.
#' @param obs1col Column number that details whether an individual is in an
#' observable stage at a given time.
#' @param nonobs1col Column number that details whether an individual is in an
#' unobservable stage at a given time.
#' @param censorcol Column number corresponding to the first entry of a censor 
#' variable.
#' @param stagecol Column number corresponding to the first entry of a column
#' designating stages.
#' @param repstrrel This is a scalar modifier for that makes the variable in
#' \code{repstr2col} equivalent to \code{repstr1col}.
#' @param fecrel This is a scalar modifier for that makes the variable in
#' \code{fec2col} equivalent to \code{fec1col}.
#' @param NAas0 If TRUE, then all NA entries for size and fecundity variables
#' will be set to 0.
#' @param NRasRep If TRUE, then will treat non-reproductive but mature
#' individuals as reproductive during stage assignment.
#' @param stassign A logical value indicating whether to assign stages.
#' @param stszcol Column number describing which size variable to use in stage 
#' estimation.
#' @param censorkeep The value of the censoring variable identifying data
#' that should be included in analysis. Defaults to 0, but may take any value
#' including NA.
#' @param censbool A logical variable determining whether NA denotes the value
#' of the censoring variable identifying data to keep.
#' 
#' @return The output is currently a 7 element list, where each element is a
#' data frame with the same number of rows.
#' 
#' @keywords internal
#' @noRd
pfj <- function(data, stageframe, noyears, firstyear, popidcol, patchidcol, individcol, blocksize, xcol, ycol, juvcol, size1col, size2col, size3col, repstr1col, repstr2col, fec1col, fec2col, alive1col, dead1col, obs1col, nonobs1col, censorcol, stagecol, repstrrel, fecrel, NAas0, NRasRep, stassign, stszcol, censbool) {
    .Call('_lefko3_pfj', PACKAGE = 'lefko3', data, stageframe, noyears, firstyear, popidcol, patchidcol, individcol, blocksize, xcol, ycol, juvcol, size1col, size2col, size3col, repstr1col, repstr2col, fec1col, fec2col, alive1col, dead1col, obs1col, nonobs1col, censorcol, stagecol, repstrrel, fecrel, NAas0, NRasRep, stassign, stszcol, censbool)
}

#' Make Vertical Data Frame Historical
#' 
#' Function \code{jpf()} powers the R function \code{\link{historicalize3}()}, creating
#' the historical, vertical structure and rearranging the data in that shape.
#'
#' @param data The horizontal data file.
#' @param stageframe The stageframe object identifying the life history model
#' being operationalized. This should be the full stageframe.
#' @param popidcol Column number corresponding to the identity of the population 
#' for each individual.
#' @param patchidcol Column number corresponding to the identity of the patch for
#' each individual.
#' @param individcol Column number corresponding to the identity of each 
#' individual.
#' @param year2col Column number of year or time step in time \emph{t}.
#' @param year3col Column number of year or time step in time \emph{t}+1.
#' @param xcol Column number corresponding to the x coordinate of each individual
#' in Cartesian space.
#' @param ycol Column number corresponding to the y coordinate of each individual
#' in Cartesian space.
#' @param juv2col Column number coding for status as a juvenile in time \emph{t}.
#' @param juv3col Column number coding for status as a juvenile in time \emph{t}+1.
#' @param sizea2col Column number corresponding to the primary size variable in
#' time \emph{t}.
#' @param sizea3col Column number corresponding to the primary size variable in
#' time \emph{t}+1.
#' @param sizeb2col Column number corresponding to the secondary size variable in
#' time \emph{t}.
#' @param sizeb3col Column number corresponding to the secondary size variable in
#' time \emph{t}+1.
#' @param sizec2col Column number corresponding to the tertiary size variable in
#' time \emph{t}.
#' @param sizec3col Column number corresponding to the tertiary size variable in
#' time \emph{t}+1.
#' @param repstra2col Column number corresponding to the main variable coding the
#' production of reproductive structures, such as flowers, in time \emph{t}.
#' @param repstra3col Column number corresponding to the main variable coding the
#' production of reproductive structures, such as flowers, in time \emph{t}+1.
#' @param repstrb2col Column number corresponding to a second variable coding the
#' production of reproductive structures, such as flowers, in time
#' @param repstrb3col Column number corresponding to a second variable coding the
#' production of reproductive structures, such as flowers, in time \emph{t}+1.
#' @param feca2col Column number corresponding to the main variable coding for
#' fecundity in time \emph{t}.
#' @param feca3col Column number corresponding to the main variable coding for
#' fecundity in time \emph{t}+1.
#' @param fecb2col Column number corresponding to a second variable coding for
#' fecundity in time \emph{t}.
#' @param fecb3col Column number corresponding to a second variable coding for
#' fecundity in time \emph{t}+1.
#' @param alive2col Column number detailing whether an individual is alive in 
#' time \emph{t}.
#' @param alive3col Column number detailing whether an individual is alive in 
#' time \emph{t}+1.
#' @param dead2col Column number detailing whether an individual is dead in 
#' time \emph{t}.
#' @param dead3col Column number detailing whether an individual is dead in 
#' time \emph{t}+1.
#' @param obs2col Column number detailing whether an individual is in an
#' observable stage in time \emph{t}.
#' @param obs3col Column number detailing whether an individual is in an
#' unobservable stage in time \emph{t}.
#' @param nonobs2col Column number detailing whether an individual is in an
#' unobservable stage in time \emph{t}.
#' @param nonobs3col Column number detailing whether an individual is in an
#' unobservable stage in time \emph{t}+1.
#' @param repstrrel This is a scalar modifier for that makes the variable in
#' \code{repstrb2col} equivalent to \code{repstra2col}.
#' @param fecrel This is a scalar modifier for that makes the variable in
#' \code{fecb2col} equivalent to \code{feca2col}.
#' @param stage2col Column number corresponding to life history stage in time \emph{t}.
#' @param stage3col Column number corresponding to life history stage in time \emph{t}+1.
#' @param censorcol Column number corresponding to a censor variable within the 
#' dataset.
#' @param NAas0 If TRUE, then all NA entries for size and fecundity variables
#' will be set to 0.
#' @param NRasRep If TRUE, then will treat non-reproductive but mature
#' individuals as reproductive during stage assignment.
#' @param stassign A logical value indicating whether to assign stages.
#' @param stszcol Column number describing which size variable to use in stage 
#' estimation.
#' @param censbool A logical variable determining whether NA denotes the value
#' of the censoring variable identifying data to keep.
#' 
#' @return The output is currently a 7 element list, where each element is a
#' data frame with the same number of rows.
#' 
#' @keywords internal
#' @noRd
jpf <- function(data, stageframe, popidcol, patchidcol, individcol, year2col, year3col, xcol, ycol, juv2col, juv3col, sizea2col, sizea3col, sizeb2col, sizeb3col, sizec2col, sizec3col, repstra2col, repstra3col, repstrb2col, repstrb3col, feca2col, feca3col, fecb2col, fecb3col, alive2col, alive3col, dead2col, dead3col, obs2col, obs3col, nonobs2col, nonobs3col, repstrrel, fecrel, stage2col, stage3col, censorcol, NAas0, NRasRep, stassign, stszcol, censbool) {
    .Call('_lefko3_jpf', PACKAGE = 'lefko3', data, stageframe, popidcol, patchidcol, individcol, year2col, year3col, xcol, ycol, juv2col, juv3col, sizea2col, sizea3col, sizeb2col, sizeb3col, sizec2col, sizec3col, repstra2col, repstra3col, repstrb2col, repstrb3col, feca2col, feca3col, fecb2col, fecb3col, alive2col, alive3col, dead2col, dead3col, obs2col, obs3col, nonobs2col, nonobs3col, repstrrel, fecrel, stage2col, stage3col, censorcol, NAas0, NRasRep, stassign, stszcol, censbool)
}

#' Create Core Dataframe for Matrix Estimation
#' 
#' Function \code{theoldpizzle()} create a data frame object spread across three
#' 20-element long list objects that is used by \code{jerzeibalowski()} to estimate
#' function-derived matrices.
#'
#' @param StageFrame The stageframe object identifying the life history model
#' being operationalized.
#' @param OverWrite The overwrite table used in analysis, as modifed by 
#' \code{.overwrite_reassess}.
#' @param repmatrix The reproductive matrix used in analysis.
#' @param finalage The final age to be used in analysis.
#' @param style The style of analysis, where 0 is historical, 1 is ahistorical,
#' and 2 is age-by-stage.
#' @param cont Denotes whether age-by-stage matrix continues past the final age.
#' 
#' @return The output is currently a three element list, where each element is a
#' data frame with the same number of rows. These are combined into one dataframe
#' by \code{\link{flefko3}()}, \code{\link{flefko2}()}, and \code{\link{aflefko2}()}.
#' 
#' @keywords internal
#' @noRd
theoldpizzle <- function(StageFrame, OverWrite, repmatrix, finalage, style, cont) {
    .Call('_lefko3_theoldpizzle', PACKAGE = 'lefko3', StageFrame, OverWrite, repmatrix, finalage, style, cont)
}

#' Estimate All Elements in Function-based Population Projection Matrices
#' 
#' Function \code{jerzeibalowski} swiftly calculates matrix elements in function-based
#' population projection matrices. Used in \code{\link{flefko3}()}, \code{\link{flefko2}()},
#' and \code{\link{aflefko2}()}.
#' 
#' @param ppy A data frame with one row, showing the population, patch, and year.
#' @param AllStages A large data frame giving all required inputs for vital rate
#' estimation other than the vital rate model coefficients themselves. Contains
#' a row for each ultimate matrix element.
#' @param survproxy List of coefficients estimated in model of survival.
#' @param obsproxy List of coefficients estimated in model of observation.
#' @param sizeproxy List of coefficients estimated in model of size.
#' @param repstproxy List of coefficients estimated in model of reproductive 
#' status.
#' @param fecproxy List of coefficients estimated in model of fecundity.
#' @param jsurvproxy List of coefficients estimated in model of juvenile
#' survival.
#' @param jobsproxy List of coefficients estimated in model of juvenile
#' observation.
#' @param jsizeproxy List of coefficients estimated in model of juvenile size.
#' @param jrepstproxy List of coefficients estimated in model of juvenile
#' reproductive status.
#' @param survdev Scalar value to be added to the y-intercept of the linear model
#' of survival probability.
#' @param obsdev Scalar value to be added to the y-intercept of the linear model
#' of observation probability.
#' @param sizedev Scalar value to be added to the y-intercept of the linear model
#' of size transition.
#' @param repstdev Scalar value to be added to the y-intercept of the linear model
#' of reproduction probability.
#' @param fecdev Scalar value to be added to the y-intercept of the linear model
#' of fecundity.
#' @param jsurvdev Scalar value to be added to the y-intercept of the linear model
#' of juvenile survival probability.
#' @param jobsdev Scalar value to be added to the y-intercept of the linear model
#' of juvenile observation probability.
#' @param jsizedev Scalar value to be added to the y-intercept of the linear model
#' of juvenile size transition.
#' @param jrepstdev Scalar value to be added to the y-intercept of the linear model
#' of juvenile reproduction probability.
#' @param matrixdim Number of rows (and columns) in the final matrix.
#' @param fecmod A scalar multiplier for fecundity.
#' @param summedvars Summed variance-covariance terms in Poisson size distribution.
#' @param sigma Standard deviation of Gaussian size distribution.
#' @param jsummedvars Summed variance-covariance terms in Poisson juvenile size
#' distribution.
#' @param jsigma Standard deviation of Gaussian juvenile size distribution.
#' @param maxsize The maximum size to be used in element estimation.
#' @param sizedist Designates whether size is Gaussian (2), Poisson (0), or
#' negative binomial (1) distributed.
#' @param fecdist Designates whether fecundity is Gaussian (2), Poisson (0), or
#' negative binomial (1) distributed.
#' @param negfec Logical value denoting whether to change negative estimated
NULL

#' Estimate All Elements in Raw Historical Matrix
#' 
#' Function \code{specialpatrolgroup} swiftly calculates matrix transitions in raw
#' historical matrices, and serves as the core workhorse function behind \code{\link{rlefko3}()}.
#' 
#' @param sge9l The Allstages data frame developed for rlefko3() covering stage
#' pairs across times \emph{t}+1, \emph{t} and \emph{t}-1. Generally termed \code{stageexpansion9}.
#' @param sge3 The data frame covering all stages in times \emph{t} and \emph{t}-1.
#' Generally termed \code{stageexpansion3}.
#' @param MainData The demographic dataset modified to hold \code{usedfec} columns.
#' @param StageFrame The full stageframe for the analysis.
#' 
#' @return List of three matrices, including the survival-transition (U) matrix, the 
#' fecundity matrix (F), and the sum (A) matrix, with A first.
#' 
#' @keywords internal
#' @noRd
specialpatrolgroup <- function(sge9l, sge3, MainData, StageFrame) {
    .Call('_lefko3_specialpatrolgroup', PACKAGE = 'lefko3', sge9l, sge3, MainData, StageFrame)
}

#' Estimate All Elements in Raw Ahistorical Population Projection Matrices
#' 
#' Function \code{normalpatrolgroup} swiftly calculates matrix transitions in raw
#' ahistorical matrices, and serves as the core workhorse function behind \code{\link{rlefko2}()}.
#' 
#' @param sge3 The Allstages data frame developed for rlefko2() covering stage
#' pairs across times \emph{t}+1 and \emph{t}. Generally termed \code{stageexpansion3}.
#' @param sge2 The data frame covering all stages in time \emph{t}. Generally termed
#' \code{stageexpansion2}.
#' @param MainData The demographic dataset modified to hold \code{usedfec} columns.
#' @param StageFrame The full stageframe for the analysis.
#' 
#' @return List of three matrices, including the survival-transition (U) matrix, the 
#' fecundity matrix (F), and the sum (A) matrix, with A first.
#' 
#' @keywords internal
#' @noRd
normalpatrolgroup <- function(sge3, sge2, MainData, StageFrame) {
    .Call('_lefko3_normalpatrolgroup', PACKAGE = 'lefko3', sge3, sge2, MainData, StageFrame)
}

#' 
#' @return A list of 3 matrices, including the main MPM (A), the survival-transition
#' matrix (U), anf a fecundity matrix (F). With tweaking, can also produce a 4 column 
#' matrix showing survival probability, observation probability, reproduction
#' probability, and size transition probability, for each element of the final MPM.
#' 
#' @keywords internal
#' @noRd
jerzeibalowski <- function(ppy, AllStages, survproxy, obsproxy, sizeproxy, repstproxy, fecproxy, jsurvproxy, jobsproxy, jsizeproxy, jrepstproxy, survdev, obsdev, sizedev, repstdev, fecdev, jsurvdev, jobsdev, jsizedev, jrepstdev, matrixdim, fecmod, summedvars, sigma, jsummedvars, jsigma, maxsize, sizedist, fecdist, negfec) {
    .Call('_lefko3_jerzeibalowski', PACKAGE = 'lefko3', ppy, AllStages, survproxy, obsproxy, sizeproxy, repstproxy, fecproxy, jsurvproxy, jobsproxy, jsizeproxy, jrepstproxy, survdev, obsdev, sizedev, repstdev, fecdev, jsurvdev, jobsdev, jsizedev, jrepstdev, matrixdim, fecmod, summedvars, sigma, jsummedvars, jsigma, maxsize, sizedist, fecdist, negfec)
}

#' Vectorize Matrix for Historical Mean Matrix Estimation
#' 
#' Function \code{flagrantcrap()} vectorizes core indices of matrices
#' input as list elements.
#' 
#' @param Xmat A matrix originally a part of a list object.
#' @param allindices A vector of indices to remove from the matrix
#' 
#' @return A column vector of certain elements from the input matrix.
#' 
#' @keywords internal
#' @noRd
flagrantcrap <- function(Xmat, allindices) {
    .Call('_lefko3_flagrantcrap', PACKAGE = 'lefko3', Xmat, allindices)
}

#' Vectorize Matrix for Ahistorical Mean Matrix Estimation
#' 
#' Function \code{moreflagrantcrap()} vectorizes matrices input as list elements.
#' 
#' @param Xmat A matrix originally a part of a list object.
#' 
#' @return A column vector of the input matrix.
#' 
#' @keywords internal
#' @noRd
moreflagrantcrap <- function(Xmat) {
    .Call('_lefko3_moreflagrantcrap', PACKAGE = 'lefko3', Xmat)
}

#' Estimates Mean LefkoMat Object for Historical MPM
#' 
#' Function \code{turbogeodiesel()} estimates mean historical population projection matrices,
#' treating the mean as element-wise arithmetic.
#' 
#' @param loy A data frame denoting the population, patch, and time step designation
#' of each matrix. Includes a total of 9 variables.
#' @param Umats A matrix with all U matrices turned into columns.
#' @param Fmats A matrix with all F matrices turned into columns.
#' @param stages This is the core stageframe held by \code{mats}, equivalent
#' to \code{ahstages}.
#' @param hstages This is the \code{hstages} object held by \code{mats}.
#' @param modelqc This is the \code{modelqc} or \code{dataqc} portion of \code{mats}.
#' @param patchmats A logical value stating whether to estimate patch-level means.
#' @param popmats A logical value stating whether to estimate population-level means.
#' 
#' @return A list using ther basic blueprint of a lefkoMat object.
#' 
#' @keywords internal
#' @noRd
turbogeodiesel <- function(loy, Umats, Fmats, stages, hstages, modelqc, patchmats, popmats) {
    .Call('_lefko3_turbogeodiesel', PACKAGE = 'lefko3', loy, Umats, Fmats, stages, hstages, modelqc, patchmats, popmats)
}

#' Estimates Mean LefkoMat Object for Ahistorical MPM
#' 
#' Function \code{geodiesel()} estimates mean ahistorical population projection matrices,
#' treating the mean as element-wise arithmetic.
#' 
#' @param loy A data frame denoting the population, patch, and time step designation
#' of each matrix. Includes a total of 9 variables.
#' @param Umats A matrix with all U matrices turned into columns.
#' @param Fmats A matrix with all F matrices turned into columns.
#' @param stages This is the core stageframe held by \code{mats}, equivalent
#' to \code{ahstages}.
#' @param modelqc This is the \code{modelqc} or \code{dataqc} portion of \code{mats}.
#' @param patchmats A logical value stating whether to estimate patch-level means.
#' @param popmats A logical value stating whether to estimate population-level means.
#' 
#' @return A list using th4 basic blueprint of a LefkoMat object.
#' 
#' @keywords internal
#' @noRd
geodiesel <- function(loy, Umats, Fmats, stages, modelqc, patchmats, popmats) {
    .Call('_lefko3_geodiesel', PACKAGE = 'lefko3', loy, Umats, Fmats, stages, modelqc, patchmats, popmats)
}

#' Complete Full Eigen Analysis of a Single Dense Matrix
#' 
#' \code{decomp3()} returns all eigenvalues, right eigenvectors, and left
#' eigenvectors estimated for a matrix by the \code{eig_gen}() function
#' in the C++ Armadillo library. Works with dense matrices.
#' 
#' @param Amat A population projection matrix of class \code{matrix}.
#'
#' @return This function returns all estimated eigenvalues, right
#' eigenvectors, and left eigenvectors of a single matrix. This output is
#' provided as a list with three parts, named appropriately.
#' 
#' @keywords internal
#' @noRd
decomp3 <- function(Amat) {
    .Call('_lefko3_decomp3', PACKAGE = 'lefko3', Amat)
}

#' Complete Full Eigen Analysis of a Single Sparse Matrix
#' 
#' \code{decomp3sp()} returns all eigenvalues, right eigenvectors, and left
#' eigenvectors estimated for a matrix by the \code{eigs_gen}() function
#' in the C++ Armadillo library. Works with sparse matrices.
#' 
#' @param Amat A population projection matrix of class \code{matrix}.
#'
#' @return This function returns all estimated eigenvalues, right
#' eigenvectors, and left eigenvectors of a single matrix. This output is
#' provided as a list with three parts, named appropriately.
#' 
#' @keywords internal
#' @noRd
decomp3sp <- function(Amat) {
    .Call('_lefko3_decomp3sp', PACKAGE = 'lefko3', Amat)
}

#' Estimate Deterministic Population Growth Rate of a Dense Matrix
#' 
#' \code{lambda3matrix()} returns the dominant eigenvalue of a single
#' dense projection matrix.
#' 
#' @param Amat A population projection matrix of class \code{matrix}.
#'
#' @return This function returns the dominant eigenvalue of the matrix. This
#' is given as the largest real part of all eigenvalues estimated via the 
#' \code{eig_gen}() function in the C++ Armadillo library.
#' 
#' @keywords internal
#' @noRd
lambda3matrix <- function(Amat) {
    .Call('_lefko3_lambda3matrix', PACKAGE = 'lefko3', Amat)
}

#' Estimate Deterministic Population Growth Rate of a Sparse Matrix
#' 
#' \code{lambda3matrixsp()} returns the dominant eigenvalue of a single
#' sparse projection matrix. This function can handle large and sparse 
#' matrices, and so can be used with large historical matrices, IPMs, 
#' age x stage matrices, as well as smaller ahistorical matrices.
#' 
#' @param Amat A population projection matrix of class \code{matrix}.
#'
#' @return This function returns the dominant eigenvalue of the matrix. This
#' is given as the largest real part of all eigenvalues estimated via the 
#' \code{eigs_gen}() function in the C++ Armadillo library.
#' 
#' @keywords internal
#' @noRd
lambda3matrixsp <- function(Amat) {
    .Call('_lefko3_lambda3matrixsp', PACKAGE = 'lefko3', Amat)
}

#' Estimate Stable Stage Distribution for a Dense Population Matrix
#' 
#' \code{ss3matrix()} returns the stable stage distribution for a 
#' dense population matrix.
#' 
#' @param Amat A population projection matrix of class \code{matrix}.
#' 
#' @return This function returns the stable stage distribution corresponding to
#' the input matrix. The stable stage distribution is given as the right 
#' eigenvector associated with largest real part of the eigenvalues estimated 
#' for the matrix via the \code{eig_gen}() function in the C++ Armadillo 
#' library, divided by the sum of the associated right eigenvector. 
#' 
#' @seealso \code{\link{stablestage3}()}
#' @seealso \code{\link{stablestage3.lefkoMat}()}
#' 
#' @keywords internal
#' @noRd
ss3matrix <- function(Amat) {
    .Call('_lefko3_ss3matrix', PACKAGE = 'lefko3', Amat)
}

#' Estimate Stable Stage Distribution for a Sparse Population Matrix
#' 
#' \code{ss3matrixsp()} returns the stable stage distribution for a 
#' sparse population matrix. This function can handle large and sparse 
#' matrices, and so can be used with large historical matrices, IPMs, 
#' age x stage matrices, as well as smaller ahistorical matrices.
#' 
#' @param Amat A population projection matrix of class \code{matrix}.
#' 
#' @return This function returns the stable stage distribution corresponding to
#' the input matrix. The stable stage distribution is given as the right 
#' eigenvector associated with largest real part of the eigenvalues estimated 
#' for the matrix via the \code{eigs_gen}() function in the C++ Armadillo 
#' library, divided by the sum of the associated right eigenvector. 
#' 
#' @seealso \code{\link{stablestage3}()}
#' @seealso \code{\link{stablestage3.lefkoMat}()}
#' 
#' @keywords internal
#' @noRd
ss3matrixsp <- function(Amat) {
    .Call('_lefko3_ss3matrixsp', PACKAGE = 'lefko3', Amat)
}

#' Estimate Reproductive Value for a Dense Population Matrix
#' 
#' \code{rv3matrix()} returns the reproductive values for stages in a 
#' dense population matrix. The function provides standard reproductive 
#' values, meaning that the overall reproductive values of basic life 
#' history stages in a historical matrix are not provided (the 
#' \code{\link{repvalue3.lefkoMat}()} function estimates these on the basis 
#' of stage description information provided in the \code{lefkoMat} object 
#' used as input in that function).
#' 
#' @param Amat A population projection matrix.
#' 
#' @return This function returns a vector characterizing the 
#' reproductive values for stages of a population projection matrix. This is 
#' given as the left eigenvector associated with largest real part of the
#' dominant eigenvalue estimated via the \code{eig_gen}() function in the C++ 
#' Armadillo library, divided by the first non-zero element of the left 
#' eigenvector. 
#' 
#' @seealso \code{\link{repvalue3}()}
#' @seealso \code{\link{repvalue3.lefkoMat}()}
#' 
#' @keywords internal
#' @noRd
rv3matrix <- function(Amat) {
    .Call('_lefko3_rv3matrix', PACKAGE = 'lefko3', Amat)
}

#' Estimate Reproductive Value for a Sparse Population Matrix
#' 
#' \code{rv3matrixsp()} returns the reproductive values for stages in a 
#' sparse population matrix. The function provides standard reproductive 
#' values, meaning that the overall reproductive values of basic life 
#' history stages in a historical matrix are not provided (the 
#' \code{\link{repvalue3.lefkoMat}()} function estimates these on the basis 
#' of stage description information provided in the \code{lefkoMat} object 
#' used as input in that function). This function can handle large and 
#' sparse matrices, and so can be used with large historical matrices, IPMs, 
#' age x stage matrices, as well as smaller ahistorical 
#' matrices.
#' 
#' @param Amat A population projection matrix.
#' 
#' @return This function returns a vector characterizing the 
#' reproductive values for stages of a population projection matrix. This is 
#' given as the left eigenvector associated with largest real part of the
#' dominant eigenvalue estimated via the \code{eigs_gen}() function in the C++ 
#' Armadillo library, divided by the first non-zero element of the left 
#' eigenvector. 
#' 
#' @seealso \code{\link{repvalue3}()}
#' @seealso \code{\link{repvalue3.lefkoMat}()}
#' 
#' @keywords internal
#' @noRd
rv3matrixsp <- function(Amat) {
    .Call('_lefko3_rv3matrixsp', PACKAGE = 'lefko3', Amat)
}

#' Estimate Sensitivities for a Dense Population Matrix
#' 
#' \code{sens3matrix()} returns the sensitivity of lambda with respect
#' to each element in a dense matrix. This is accomplished via the
#' \code{eig_gen}() function in the C++ Armadillo library.
#' 
#' @param Amat A population projection matrix.
#' 
#' @return This function returns a matrix of sensitivities. 
#' 
#' @keywords internal
#' @noRd
sens3matrix <- function(Amat) {
    .Call('_lefko3_sens3matrix', PACKAGE = 'lefko3', Amat)
}

#' Estimate Sensitivities for a Sparse Population Matrix
#' 
#' \code{sens3matrixsp()} returns the sensitivity of lambda with respect
#' to each element in a sparse matrix. This is accomplished via the
#' \code{eig_gen}() function in the C++ Armadillo library.
#' 
#' @param Amat A population projection matrix.
#' 
#' @return This function returns a matrix of sensitivities. 
#' 
#' @keywords internal
#' @noRd
sens3matrixsp <- function(Amat) {
    .Call('_lefko3_sens3matrixsp', PACKAGE = 'lefko3', Amat)
}

#' Estimate Sensitivities for a Historical LefkoMat Object
#' 
#' \code{sens3hlefko()} returns the sensitivity of lambda with respect
#' to each historical stage-pair in the matrix, and the associated
#' sensitivity for each life history stage. This is accomplished via the 
#' \code{eigs_gen}() function in the C++ Armadillo library.
#' 
#' @param Amat A population projection matrix.
#' @param ahstages An integar vector of unique ahistorical stages.
#' @param hstages An integar vector of unique historical stage pairs.
#' 
#' @return This function returns a list with two sensitivity matrices:
#' \item{h_smat}{Matrix of sensitivities corresponding to the historical matrix.}
#' \item{ah_smat}{Matrix of sensitivities corresponding to the ahistorical
#' matrix.}
#' 
#' @keywords internal
#' @noRd
sens3hlefko <- function(Amat, ahstages, hstages) {
    .Call('_lefko3_sens3hlefko', PACKAGE = 'lefko3', Amat, ahstages, hstages)
}

#' Estimate Elasticities for a Dense Population Matrix
#' 
#' \code{elas3matrix()} returns the elasticity of lambda with respect
#' to each element in a dense matrix. This is accomplished via the
#' \code{eig_gen}() function in the C++ Armadillo library.
#' 
#' @param Amat A population projection matrix.
#' 
#' @return This function returns a matrix of elasticities. 
#' 
#' @keywords internal
#' @noRd
elas3matrix <- function(Amat) {
    .Call('_lefko3_elas3matrix', PACKAGE = 'lefko3', Amat)
}

#' Estimate Elasticities for a Sparse Population Matrix
#' 
#' \code{elas3matrixsp()} returns the elasticity of lambda with respect
#' to each element in a sparse matrix. This is accomplished via the
#' \code{eigs_gen}() function in the C++ Armadillo library.
#' 
#' @param Amat A population projection matrix.
#' 
#' @return This function returns a matrix of elasticities. 
#' 
#' @keywords internal
#' @noRd
elas3matrixsp <- function(Amat) {
    .Call('_lefko3_elas3matrixsp', PACKAGE = 'lefko3', Amat)
}

#' Estimate Elasticities for a Historical LefkoMod Object
#' 
#' \code{elas3hlefko()} returns the elasticity of lambda with respect
#' to each historical stage-pair in the matrix, and the summed elasticities
#' for each life history stage. This is accomplished via the \code{eigs_gen}()
#' function in the C++ Armadillo library.
#' 
#' @param Amat A population projection matrix.
#' @param ahstages An integar vector of unique ahistorical stages.
#' @param hstages An integar vector of unique historical stage pairs.
#' 
#' @return This function returns a list with two elasticity matrices:
#' \item{h_emat}{Matrix of elasticities corresponding to the historical matrix.}
#' \item{ah_emat}{Matrix of elasticities corresponding to the ahistorical
#' matrix, but using summed historical elasticities as the basis of estimation.}
#' 
#' @keywords internal
#' @noRd
elas3hlefko <- function(Amat, ahstages, hstages) {
    .Call('_lefko3_elas3hlefko', PACKAGE = 'lefko3', Amat, ahstages, hstages)
}

